/*
 * Copyright (C) 2012 Canonical, Ltd.
 *
 * Authors:
 *  Christian Dywan <christian.dywan@canonical.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QDebug>

#include "deevarianttext.h"
#include "deeprivate.h"

DeeVariantText::DeeVariantText(QObject *parent) :
    m_text(""), m_value(QVariant()), m_type("")
{
}

void
DeeVariantText::setText(const QString& text)
{
    m_text = text;
    GVariant *gvariant = g_variant_parse(NULL, text.toUtf8(), NULL, NULL, NULL);
    if (!gvariant)
    {
        qDebug() << "Failed to parse " << text << " to QVariant";
        m_value = QVariant();
        m_type = "";
    }
    else
    {
        m_value = QVariantFromGVariant(gvariant);
        m_type = g_variant_get_type_string(gvariant);
    }
    Q_EMIT textChanged(text);
    Q_EMIT valueChanged(m_value);
}

